@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: geography_inout.c 13149 2014-12-17 17:34:08Z pramsey $
+ * $Id: geography_inout.c 13659 2015-06-11 19:47:14Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
  * Copyright 2009-2011 Paul Ramsey <pramsey@cleverelephant.ca>
@@ -104,7 +104,7 @@ GSERIALIZED* gserialized_geography_from_lwgeom(LWGEOM *lwgeom, int32 geog_typmod
 	/* Check for typmod agreement */
 	if ( geog_typmod >= 0 )
 	{
-		postgis_valid_typmod(g_ser, geog_typmod);
+		g_ser = postgis_valid_typmod(g_ser, geog_typmod);
 		POSTGIS_DEBUG(3, "typmod and geometry were consistent");
 	}
 	else
@@ -598,9 +598,11 @@ Datum geography_from_geometry(PG_FUNCTION_ARGS)
 	** functions do the right thing.
 	*/
 	lwgeom_set_geodetic(lwgeom, true);
+	
 	/* Recalculate the boxes after re-setting the geodetic bit */
 	lwgeom_drop_bbox(lwgeom);
 	lwgeom_add_bbox(lwgeom);
+	
 	g_ser = geography_serialize(lwgeom);
 
 	/*
